@@ -604,6 +604,73 @@ impl Builder {
         Ok(self)
     }
 
+    /// Corresponds to [s2n_config_add_custom_x509_extension].
+    #[cfg(feature = "unstable-custom_x509_extensions")]
+    pub fn add_custom_x509_extension(&mut self, extension_oid: &str) -> Result<&mut Self, Error> {
+        let extension_oid_len: u32 = extension_oid
+            .len()
+            .try_into()
+            .map_err(|_| Error::INVALID_INPUT)?;
+        let extension_oid = extension_oid.as_ptr() as *mut u8;
+        unsafe {
+            s2n_config_add_custom_x509_extension(
+                self.as_mut_ptr(),
+                extension_oid,
+                extension_oid_len,
+            )
+            .into_result()
+        }?;
+        Ok(self)
+    }
+
+    /// Set a callback function to perform custom cert validation synchronously.
+    ///
+    /// Corresponds to [s2n_config_set_cert_validation_cb], but the rust callback
+    /// can only perform in synchronous mode.
+    #[cfg(feature = "unstable-crl")]
+    pub fn set_cert_validation_callback_sync<T: 'static + CertValidationCallbackSync>(
+        &mut self,
+        handler: T,
+    ) -> Result<&mut Self, Error> {
+        unsafe extern "C" fn cert_validation_cb(
+            conn_ptr: *mut s2n_connection,
+            validation_info: *mut s2n_cert_validation_info,
+            _context: *mut core::ffi::c_void,
+        ) -> libc::c_int {
+            let mut info = CertValidationInfo::from_ptr(validation_info);
+            with_context(conn_ptr, |conn, context| {
+                let callback = context.cert_validation_callback_sync.as_ref();
+                callback.map(|callback| {
+                    let accepted = callback.handle_validation(conn, &mut info).unwrap();
+                    match accepted {
+                        true => info.accept().unwrap(),
+                        false => info.reject().unwrap(),
+                    }
+                })
+            });
+            CallbackResult::Success.into()
+        }
+
+        let handler = Box::new(handler);
+        let context = unsafe {
+            // SAFETY: usage of context_mut is safe in the builder, because while
+            // it is being built, the Builder is the only reference to the config.
+            self.config.context_mut()
+        };
+        context.cert_validation_callback_sync = Some(handler);
+
+        unsafe {
+            s2n_config_set_cert_validation_cb(
+                self.as_mut_ptr(),
+                Some(cert_validation_cb),
+                core::ptr::null_mut(),
+            )
+            .into_result()?;
+        }
+
+        Ok(self)
+    }
+
     /// Set a custom callback function which is run after parsing the client hello.
     ///
     /// Corresponds to [s2n_config_set_client_hello_cb].
@@ -1027,6 +1094,8 @@ pub(crate) struct Context {
     pub(crate) renegotiate: Option<Box<dyn RenegotiateCallback>>,
     #[cfg(feature = "unstable-cert_authorities")]
     pub(crate) cert_authorities: Option<Box<dyn CertificateRequestCallback>>,
+    #[cfg(feature = "unstable-crl")]
+    pub(crate) cert_validation_callback_sync: Option<Box<dyn CertValidationCallbackSync>>,
 }
 
 impl Default for Context {
@@ -1049,6 +1118,8 @@ impl Default for Context {
             renegotiate: None,
             #[cfg(feature = "unstable-cert_authorities")]
             cert_authorities: None,
+            #[cfg(feature = "unstable-crl")]
+            cert_validation_callback_sync: None,
         }
     }
 }
@@ -1163,4 +1234,52 @@ mod tests {
 
         Ok(())
     }
+
+    #[cfg(all(
+        // The `add_custom_x509_extension` API is only exposed when its unstable feature is enabled.
+        feature = "unstable-custom_x509_extensions",
+        // The `add_custom_x509_extension` API is only supported with AWS-LC, so
+        // this test is disabled for the external build, which may link to other libcryptos.
+        not(s2n_tls_external_build),
+        // The `add_custom_x509_extension` API is currently unsupported with AWS-LC-FIPS.
+        not(feature = "fips")
+    ))]
+    #[test]
+    fn custom_critical_extensions() -> Result<(), Error> {
+        use crate::testing::*;
+
+        let certs = CertKeyPair::from_path(
+            "custom_oids/",
+            "single_oid_cert_chain",
+            "single_oid_key",
+            "ca-cert",
+        );
+        let single_oid = "1.3.187.25240.2";
+
+        for add_oid in [true, false] {
+            let config = {
+                let mut config = Builder::new();
+                config.set_security_policy(&security::DEFAULT_TLS13)?;
+                config.set_verify_host_callback(InsecureAcceptAllCertificatesHandler {})?;
+
+                if add_oid {
+                    config.add_custom_x509_extension(single_oid)?;
+                }
+
+                config.load_pem(certs.cert(), certs.key())?;
+                config.trust_pem(certs.cert())?;
+                config.build()?
+            };
+            let mut pair = TestPair::from_config(&config);
+
+            if add_oid {
+                pair.handshake()?;
+            } else {
+                let s2n_err = pair.handshake().unwrap_err();
+                assert_eq!(s2n_err.name(), "S2N_ERR_CERT_UNHANDLED_CRITICAL_EXTENSION");
+            }
+        }
+
+        Ok(())
+    }
 }
