@@ -5,21 +5,11 @@
 # based on the environment.
 
 # If S2N is operating in FIPS mode
-S2N_FIPS_MODE = 's2n_fips_mode'
+S2N_FIPS_MODE = "s2n_fips_mode"
 
 # The version of provider being used
 # (set from the S2N_LIBCRYPTO env var, which is how the original integration test works)
-S2N_PROVIDER_VERSION = 's2n_provider_version'
-
-# From S2N_USE_CRITERION env var.
-S2N_USE_CRITERION = 's2n_use_criterion'
-
-
-def is_criterion_on():
-    if _flags.get(S2N_USE_CRITERION, "off") in ["baseline", "delta"]:
-        return True
-    return False
-
+S2N_PROVIDER_VERSION = "s2n_provider_version"
 
 _flags = {}
 
