@@ -135,6 +135,7 @@ int main(int argc, char **argv)
     /* Test s2n_client_hello_has_extension with a zero-length extension */
     for (int send_sct = 0; send_sct <= 1; send_sct++) {
         DEFER_CLEANUP(struct s2n_config *config = s2n_config_new(), s2n_config_ptr_free);
+        EXPECT_OK(s2n_config_set_tls12_security_policy(config));
         EXPECT_SUCCESS(s2n_config_add_cert_chain_and_key_to_store(config, chain_and_key));
 
         /* The SCT extension is zero-length. */
@@ -313,6 +314,7 @@ int main(int argc, char **argv)
 
             struct s2n_connection *conn = NULL;
             EXPECT_NOT_NULL(conn = s2n_connection_new(S2N_CLIENT));
+            EXPECT_OK(s2n_connection_set_tls12_security_policy(conn));
             struct s2n_stuffer *hello_stuffer = &conn->handshake.io;
             conn->actual_protocol_version = i;
 
@@ -424,6 +426,7 @@ int main(int argc, char **argv)
             {
                 struct s2n_connection *conn = NULL;
                 EXPECT_NOT_NULL(conn = s2n_connection_new(S2N_CLIENT));
+                EXPECT_OK(s2n_connection_set_tls12_security_policy(conn));
                 struct s2n_stuffer *hello_stuffer = &conn->handshake.io;
 
                 EXPECT_SUCCESS(s2n_client_hello_send(conn));
@@ -444,6 +447,7 @@ int main(int argc, char **argv)
 
                 struct s2n_connection *conn = NULL;
                 EXPECT_NOT_NULL(conn = s2n_connection_new(S2N_CLIENT));
+                EXPECT_OK(s2n_config_set_tls12_security_policy(config));
                 EXPECT_SUCCESS(s2n_connection_set_config(conn, config));
                 struct s2n_stuffer *hello_stuffer = &conn->handshake.io;
 
@@ -468,7 +472,7 @@ int main(int argc, char **argv)
             {
                 struct s2n_connection *conn = NULL;
                 EXPECT_NOT_NULL(conn = s2n_connection_new(S2N_CLIENT));
-
+                EXPECT_OK(s2n_connection_set_tls12_security_policy(conn));
                 struct s2n_stuffer *hello_stuffer = &conn->handshake.io;
 
                 EXPECT_SUCCESS(s2n_client_hello_send(conn));
@@ -577,7 +581,8 @@ int main(int argc, char **argv)
             } test_cases[] = {
                 { .security_policy = "test_all_tls13", .expect_renegotiation_info = false },
                 { .security_policy = "default_tls13", .expect_renegotiation_info = true },
-                { .security_policy = "default", .expect_renegotiation_info = true },
+                /* 20240501 can only negotiate up to tls12 */
+                { .security_policy = "20240501", .expect_renegotiation_info = true },
             };
 
             for (size_t i = 0; i < s2n_array_len(test_cases); i++) {
@@ -749,7 +754,7 @@ int main(int argc, char **argv)
             EXPECT_SUCCESS(s2n_client_hello_send(conn));
             EXPECT_EQUAL(conn->actual_protocol_version, s2n_get_highest_fully_supported_tls_version());
             EXPECT_EQUAL(conn->client_protocol_version, s2n_get_highest_fully_supported_tls_version());
-            EXPECT_EQUAL(conn->client_hello_version, S2N_TLS12);
+            EXPECT_EQUAL(conn->client_hello.legacy_version, S2N_TLS12);
 
             EXPECT_SUCCESS(s2n_connection_free(conn));
         };
@@ -768,7 +773,7 @@ int main(int argc, char **argv)
             EXPECT_SUCCESS(s2n_client_hello_send(conn));
             EXPECT_EQUAL(conn->actual_protocol_version, S2N_TLS12);
             EXPECT_EQUAL(conn->client_protocol_version, S2N_TLS12);
-            EXPECT_EQUAL(conn->client_hello_version, S2N_TLS12);
+            EXPECT_EQUAL(conn->client_hello.legacy_version, S2N_TLS12);
 
             EXPECT_SUCCESS(s2n_connection_free(conn));
         };
@@ -789,7 +794,7 @@ int main(int argc, char **argv)
             EXPECT_SUCCESS(s2n_client_hello_send(client_conn));
             EXPECT_EQUAL(client_conn->actual_protocol_version, s2n_get_highest_fully_supported_tls_version());
             EXPECT_EQUAL(client_conn->client_protocol_version, s2n_get_highest_fully_supported_tls_version());
-            EXPECT_EQUAL(client_conn->client_hello_version, S2N_TLS12);
+            EXPECT_EQUAL(client_conn->client_hello.legacy_version, S2N_TLS12);
 
             /* Server configured with TLS 1.2 negotiates TLS12 version */
             EXPECT_NOT_NULL(server_conn = s2n_connection_new(S2N_SERVER));
@@ -809,7 +814,7 @@ int main(int argc, char **argv)
             EXPECT_EQUAL(server_conn->server_protocol_version, S2N_TLS12);
             EXPECT_EQUAL(server_conn->actual_protocol_version, S2N_TLS12);
             EXPECT_EQUAL(server_conn->client_protocol_version, S2N_TLS12);
-            EXPECT_EQUAL(server_conn->client_hello_version, S2N_TLS12);
+            EXPECT_EQUAL(server_conn->client_hello.legacy_version, S2N_TLS12);
 
             EXPECT_SUCCESS(s2n_connection_free(server_conn));
             EXPECT_SUCCESS(s2n_connection_free(client_conn));
@@ -1538,12 +1543,12 @@ int main(int argc, char **argv)
         EXPECT_OK(s2n_handshake_type_set_tls13_flag(server_conn, HELLO_RETRY_REQUEST));
 
         /* Second client hello has version SSLv2 */
-        server_conn->client_hello_version = S2N_SSLv2;
+        server_conn->client_hello.sslv2 = true;
 
         /* Mock having some data in the client hello */
         EXPECT_SUCCESS(s2n_stuffer_write_uint16(&server_conn->handshake.io, 100));
 
-        EXPECT_FAILURE_WITH_ERRNO(s2n_parse_client_hello(server_conn), S2N_ERR_SAFETY);
+        EXPECT_FAILURE_WITH_ERRNO(s2n_parse_client_hello(server_conn), S2N_ERR_BAD_MESSAGE);
     };
 
     /* Test s2n_client_hello_parse_message
@@ -1553,7 +1558,8 @@ int main(int argc, char **argv)
      * use JA3 fingerprints as an approximation. See s2n_fingerprint_ja3_test.c
      */
     {
-        const char *security_policies[] = { "default", "default_tls13", "test_all" };
+        /* 20240501 can only negotiate tls12 */
+        const char *security_policies[] = { "20240501", "default_tls13", "test_all" };
 
         DEFER_CLEANUP(struct s2n_config *config = s2n_config_new(), s2n_config_ptr_free);
         EXPECT_SUCCESS(s2n_config_add_cert_chain_and_key_to_store(config, chain_and_key));
@@ -1694,6 +1700,7 @@ int main(int argc, char **argv)
         {
             DEFER_CLEANUP(struct s2n_connection *client = s2n_connection_new(S2N_CLIENT),
                     s2n_connection_ptr_free);
+            EXPECT_OK(s2n_connection_set_tls12_security_policy(client));
 
             EXPECT_SUCCESS(s2n_handshake_write_header(&client->handshake.io, TLS_CLIENT_HELLO));
             EXPECT_SUCCESS(s2n_client_hello_send(client));
@@ -1751,6 +1758,7 @@ int main(int argc, char **argv)
                     s2n_config_ptr_free);
             EXPECT_NOT_NULL(config);
 
+            EXPECT_OK(s2n_config_set_tls12_security_policy(config));
             EXPECT_SUCCESS(s2n_config_add_cert_chain_and_key_to_store(config, chain_and_key));
             EXPECT_SUCCESS(s2n_connection_set_config(client_conn, config));
             EXPECT_SUCCESS(s2n_connection_set_config(server_conn, config));
@@ -1807,6 +1815,7 @@ int main(int argc, char **argv)
                     s2n_config_ptr_free);
             EXPECT_NOT_NULL(config);
 
+            EXPECT_OK(s2n_config_set_tls12_security_policy(config));
             EXPECT_SUCCESS(s2n_config_add_cert_chain_and_key_to_store(config, chain_and_key));
             EXPECT_SUCCESS(s2n_connection_set_config(server_conn, config));
 
@@ -1852,6 +1861,7 @@ int main(int argc, char **argv)
                     s2n_config_ptr_free);
             EXPECT_NOT_NULL(config);
 
+            EXPECT_OK(s2n_config_set_tls12_security_policy(config));
             EXPECT_SUCCESS(s2n_config_add_cert_chain_and_key_to_store(config, chain_and_key));
             EXPECT_SUCCESS(s2n_connection_set_config(client_conn, config));
             EXPECT_SUCCESS(s2n_connection_set_config(server_conn, config));
@@ -1921,6 +1931,7 @@ int main(int argc, char **argv)
                     s2n_config_ptr_free);
             EXPECT_NOT_NULL(config);
 
+            EXPECT_OK(s2n_config_set_tls12_security_policy(config));
             EXPECT_SUCCESS(s2n_config_add_cert_chain_and_key_to_store(config, chain_and_key));
             EXPECT_SUCCESS(s2n_connection_set_config(client_conn, config));
             EXPECT_SUCCESS(s2n_connection_set_config(server_conn, config));
@@ -1953,6 +1964,95 @@ int main(int argc, char **argv)
         };
     };
 
+    /* Test: large Client Hellos */
+    {
+        const uint16_t cipher_suites_max_length = (1 << 16) - 2;
+        const uint16_t num_of_cipher_suites_to_drop = 150;
+
+        /**
+         * S2N-TLS automatically includes TLS_EMPTY_RENEGOTIATION_INFO_SCSV in TLS 1.2 ClientHello,
+         * so we subtract 1 from the maximum number of cipher suites to reserve space for it.
+         */
+        const uint16_t max_cipher_suite_count = (cipher_suites_max_length / S2N_TLS_CIPHER_SUITE_LEN) - 1;
+
+        /* Drop 150 cipher suites from max, so that the total handshake message length won't exceed 64KB */
+        const uint16_t reduced_cipher_suite_count = max_cipher_suite_count - num_of_cipher_suites_to_drop;
+
+        uint16_t cipher_suites_counts[] = { reduced_cipher_suite_count, max_cipher_suite_count };
+
+        for (size_t i = 0; i < s2n_array_len(cipher_suites_counts); i++) {
+            DEFER_CLEANUP(struct s2n_config *server_config = s2n_config_new(), s2n_config_ptr_free);
+            EXPECT_NOT_NULL(server_config);
+            EXPECT_OK(s2n_config_set_tls12_security_policy(server_config));
+            EXPECT_SUCCESS(s2n_config_add_cert_chain_and_key_to_store(server_config, chain_and_key));
+
+            /* We need to generate a large Client Hello.
+             * We do this by manipulating the number of cipher suites,
+             * which is the easiest way to make Client Hello large.
+             */
+            uint16_t cipher_suites_count = cipher_suites_counts[i];
+            struct s2n_cipher_suite *test_cipher_suites[UINT16_MAX] = { 0 };
+            for (size_t j = 0; j < cipher_suites_count; j++) {
+                test_cipher_suites[j] = &s2n_rsa_with_aes_128_gcm_sha256;
+            }
+            const struct s2n_cipher_preferences test_cipher_suites_preferences = {
+                .count = cipher_suites_count,
+                .suites = test_cipher_suites,
+            };
+            const struct s2n_security_policy *default_policy = NULL;
+            /* 20240501 is a policy that can only negotiate tls12 */
+            EXPECT_SUCCESS(s2n_find_security_policy_from_version("20240501", &default_policy));
+            struct s2n_security_policy test_security_policy = *default_policy;
+            test_security_policy.cipher_preferences = &test_cipher_suites_preferences;
+
+            DEFER_CLEANUP(struct s2n_connection *client = s2n_connection_new(S2N_CLIENT),
+                    s2n_connection_ptr_free);
+            EXPECT_NOT_NULL(client);
+            EXPECT_SUCCESS(s2n_connection_set_blinding(client, S2N_SELF_SERVICE_BLINDING));
+            client->security_policy_override = &test_security_policy;
+
+            DEFER_CLEANUP(struct s2n_connection *server = s2n_connection_new(S2N_SERVER),
+                    s2n_connection_ptr_free);
+            EXPECT_NOT_NULL(server);
+            EXPECT_SUCCESS(s2n_connection_set_config(server, server_config));
+            EXPECT_SUCCESS(s2n_connection_set_blinding(server, S2N_SELF_SERVICE_BLINDING));
+            server->security_policy_override = &test_security_policy;
+
+            DEFER_CLEANUP(struct s2n_test_io_stuffer_pair io_pair = { 0 }, s2n_io_stuffer_pair_free);
+            EXPECT_OK(s2n_io_stuffer_pair_init(&io_pair));
+            EXPECT_OK(s2n_connections_set_io_stuffer_pair(client, server, &io_pair));
+
+            /**
+             * Write Client Hello into io_pair.server_in. 
+             * The server_in buffer contains the Client Hello message plus a 5-byte record header.
+             */
+            s2n_blocked_status blocked = S2N_NOT_BLOCKED;
+            EXPECT_FAILURE_WITH_ERRNO(s2n_negotiate(client, &blocked), S2N_ERR_IO_BLOCKED);
+
+            /* Add one extra cipher suite length to account for TLS_EMPTY_RENEGOTIATION_INFO_SCSV */
+            uint16_t cipher_suites_length = (cipher_suites_count + 1) * S2N_TLS_CIPHER_SUITE_LEN;
+
+            if (cipher_suites_length < cipher_suites_max_length) {
+                /**
+                 * The Client Hello message size should be less than S2N_MAXIMUM_HANDSHAKE_MESSAGE_LENGTH, even with
+                 * the five byte record header.
+                 */
+                EXPECT_TRUE(s2n_stuffer_data_available(&io_pair.server_in) < S2N_MAXIMUM_HANDSHAKE_MESSAGE_LENGTH);
+                EXPECT_OK(s2n_negotiate_test_server_and_client_until_message(server, client, SERVER_HELLO));
+            } else {
+                /**
+                 * When using maximum cipher suites, the Client Hello message size exceeds 
+                 * S2N_MAXIMUM_HANDSHAKE_MESSAGE_LENGTH by more than five byte.
+                 * 
+                 * Hence, if server_in's available data is greater than S2N_MAXIMUM_HANDSHAKE_MESSAGE_LENGTH,
+                 * then the Client Hello itself exceeds the maximum allowed size, even after accounting for the record header.
+                 */
+                EXPECT_TRUE(s2n_stuffer_data_available(&io_pair.server_in) > S2N_MAXIMUM_HANDSHAKE_MESSAGE_LENGTH);
+                EXPECT_ERROR_WITH_ERRNO(s2n_negotiate_test_server_and_client_until_message(server, client, SERVER_HELLO), S2N_ERR_BAD_MESSAGE);
+            }
+        }
+    }
+
     EXPECT_SUCCESS(s2n_cert_chain_and_key_free(chain_and_key));
     EXPECT_SUCCESS(s2n_cert_chain_and_key_free(ecdsa_chain_and_key));
     END_TEST();
