@@ -19,35 +19,35 @@
 #include "crypto/s2n_rsa_pss.h"
 #include "s2n_test.h"
 #include "testlib/s2n_testlib.h"
+#include "tls/policy/s2n_policy_feature.h"
 #include "tls/s2n_kem.h"
 #include "tls/s2n_signature_algorithms.h"
 #include "tls/s2n_tls.h"
 
-struct s2n_supported_cert {
-    struct s2n_cert_chain_and_key *cert;
-    size_t start_index;
-};
+#define S2N_TEST_CERT_UNSUPPORTED UINT64_MAX
 
-static S2N_RESULT s2n_test_security_policies_compatible(const struct s2n_security_policy *policy,
-        const char *default_policy, struct s2n_cert_chain_and_key *cert_chain)
+static S2N_RESULT s2n_test_security_policies_compatible_for_policy(const struct s2n_security_policy *policy,
+        const struct s2n_security_policy *other_policy, struct s2n_cert_chain_and_key *cert_chain)
 {
     DEFER_CLEANUP(struct s2n_config *server_config = s2n_config_new(),
             s2n_config_ptr_free);
     RESULT_GUARD_POSIX(s2n_config_add_cert_chain_and_key_to_store(server_config, cert_chain));
+    RESULT_GUARD_POSIX(s2n_config_set_max_blinding_delay(server_config, 0));
 
     DEFER_CLEANUP(struct s2n_config *client_config = s2n_config_new(),
             s2n_config_ptr_free);
     RESULT_GUARD_POSIX(s2n_config_set_unsafe_for_testing(client_config));
+    RESULT_GUARD_POSIX(s2n_config_set_max_blinding_delay(client_config, 0));
 
     DEFER_CLEANUP(struct s2n_connection *server = s2n_connection_new(S2N_SERVER),
             s2n_connection_ptr_free);
     RESULT_GUARD_POSIX(s2n_connection_set_config(server, server_config));
-    RESULT_GUARD_POSIX(s2n_connection_set_cipher_preferences(server, default_policy));
+    RESULT_GUARD_POSIX(s2n_connection_set_security_policy(server, other_policy));
 
     DEFER_CLEANUP(struct s2n_connection *client = s2n_connection_new(S2N_CLIENT),
             s2n_connection_ptr_free);
     RESULT_GUARD_POSIX(s2n_connection_set_config(client, client_config));
-    client->security_policy_override = policy;
+    RESULT_GUARD_POSIX(s2n_connection_set_security_policy(client, policy));
 
     DEFER_CLEANUP(struct s2n_test_io_pair test_io_pair = { 0 },
             s2n_io_pair_close);
@@ -58,14 +58,42 @@ static S2N_RESULT s2n_test_security_policies_compatible(const struct s2n_securit
     return S2N_RESULT_OK;
 }
 
+static S2N_RESULT s2n_test_security_policies_compatible(const struct s2n_security_policy *policy,
+        const char *version, struct s2n_cert_chain_and_key *cert_chain)
+{
+    const struct s2n_security_policy *other_policy = NULL;
+    RESULT_GUARD_POSIX(s2n_find_security_policy_from_version(version, &other_policy));
+    RESULT_GUARD(s2n_test_security_policies_compatible_for_policy(policy, other_policy, cert_chain));
+    return S2N_RESULT_OK;
+}
+
+static S2N_RESULT s2n_test_default_backwards_compatible_for_policy(const struct s2n_security_policy *default_policy,
+        const struct s2n_security_policy **versioned_policies, size_t versioned_policies_count,
+        const struct s2n_test_cert_chain_list *cert_chains)
+{
+    RESULT_ENSURE_REF(default_policy);
+    RESULT_ENSURE_REF(versioned_policies);
+    RESULT_ENSURE_REF(cert_chains);
+
+    for (size_t policy_i = 0; policy_i < versioned_policies_count; policy_i++) {
+        for (size_t cert_i = 0; cert_i < cert_chains->count; cert_i++) {
+            if (policy_i < cert_chains->chains[cert_i].supported) {
+                continue;
+            }
+            RESULT_GUARD(s2n_test_security_policies_compatible_for_policy(
+                    versioned_policies[policy_i],
+                    default_policy,
+                    cert_chains->chains[cert_i].chain));
+        }
+    }
+
+    return S2N_RESULT_OK;
+}
+
 static S2N_RESULT s2n_test_default_backwards_compatible(const char *default_version,
         const struct s2n_security_policy **versioned_policies, size_t versioned_policies_count,
-        const struct s2n_supported_cert *supported_certs, size_t supported_certs_count)
+        const struct s2n_test_cert_chain_list *cert_chains)
 {
-    RESULT_ENSURE_REF(default_version);
-    RESULT_ENSURE_REF(versioned_policies);
-    RESULT_ENSURE_REF(supported_certs);
-
     /* The list of versioned policies MUST be kept up to date so that
      * we continue testing against all past defaults.
      */
@@ -76,17 +104,10 @@ static S2N_RESULT s2n_test_default_backwards_compatible(const char *default_vers
         FAIL_MSG("New default policy MUST be added to versioning test");
     }
 
-    for (size_t policy_i = 0; policy_i < versioned_policies_count; policy_i++) {
-        for (size_t cert_i = 0; cert_i < supported_certs_count; cert_i++) {
-            if (policy_i < supported_certs[cert_i].start_index) {
-                continue;
-            }
-            RESULT_GUARD(s2n_test_security_policies_compatible(
-                    versioned_policies[policy_i],
-                    default_version,
-                    supported_certs[cert_i].cert));
-        }
-    }
+    const struct s2n_security_policy *default_policy = NULL;
+    RESULT_GUARD_POSIX(s2n_find_security_policy_from_version(default_version, &default_policy));
+    RESULT_GUARD(s2n_test_default_backwards_compatible_for_policy(default_policy,
+            versioned_policies, versioned_policies_count, cert_chains));
 
     return S2N_RESULT_OK;
 }
@@ -196,9 +217,9 @@ int main(int argc, char **argv)
         EXPECT_FALSE(s2n_pq_kem_is_extension_required(security_policy));
         EXPECT_NULL(security_policy->kem_preferences->kems);
         EXPECT_EQUAL(0, security_policy->kem_preferences->kem_count);
-        EXPECT_NULL(security_policy->kem_preferences->tls13_kem_groups);
-        EXPECT_EQUAL(0, security_policy->kem_preferences->tls13_kem_group_count);
-        EXPECT_FALSE(s2n_security_policy_supports_tls13(security_policy));
+        EXPECT_EQUAL(security_policy->kem_preferences, &kem_preferences_pq_tls_1_3_ietf_2025_07);
+        EXPECT_EQUAL(3, security_policy->kem_preferences->tls13_kem_group_count);
+        EXPECT_TRUE(s2n_security_policy_supports_tls13(security_policy));
 
         security_policy = NULL;
         EXPECT_SUCCESS(s2n_find_security_policy_from_version("default_tls13", &security_policy));
@@ -288,8 +309,6 @@ int main(int argc, char **argv)
 
     {
         char tls12_only_security_policy_strings[][255] = {
-            "default",
-            "default_fips",
             "ELBSecurityPolicy-TLS-1-0-2015-04",
             "ELBSecurityPolicy-TLS-1-0-2015-05",
             "ELBSecurityPolicy-2016-08",
@@ -343,6 +362,8 @@ int main(int argc, char **argv)
         }
 
         char tls13_security_policy_strings[][255] = {
+            "default",
+            "default_fips",
             "default_tls13",
             "test_all",
             "test_all_tls13",
@@ -360,6 +381,17 @@ int main(int argc, char **argv)
             "CloudFront-TLS-1-2-2019",
             "CloudFront-TLS-1-2-2021",
             "CloudFront-TLS-1-2-2021-ChaCha20-Boosted",
+            /* CloudFront upstream facing */
+            "CloudFront-Upstream-2025",
+            "CloudFront-Upstream-2025-PQ",
+            "CloudFront-Upstream-TLS-1-0-2025",
+            "CloudFront-Upstream-TLS-1-0-2025-PQ",
+            "CloudFront-Upstream-TLS-1-1-2025",
+            "CloudFront-Upstream-TLS-1-1-2025-PQ",
+            "CloudFront-Upstream-TLS-1-2-2025",
+            "CloudFront-Upstream-TLS-1-2-2025-PQ",
+            "CloudFront-Upstream-TLS-1-3-2025",
+            "CloudFront-Upstream-TLS-1-3-2025-PQ",
             /* AWS Common Runtime SDK */
             "AWS-CRT-SDK-SSLv3.0",
             "AWS-CRT-SDK-TLSv1.0",
@@ -816,9 +848,9 @@ int main(int argc, char **argv)
         if (s2n_is_tls13_fully_supported()) {
             /* 20250211 */
             {
-                EXPECT_OK(s2n_test_security_policies_compatible(&security_policy_rfc9151, "default_tls13", ecdsa_sha384_chain_and_key));
-                EXPECT_OK(s2n_test_security_policies_compatible(&security_policy_rfc9151, "default_fips", ecdsa_sha384_chain_and_key));
-                EXPECT_OK(s2n_test_security_policies_compatible(&security_policy_rfc9151, "20250211", ecdsa_sha384_chain_and_key));
+                EXPECT_OK(s2n_test_security_policies_compatible(&security_policy_20250429, "default_tls13", ecdsa_sha384_chain_and_key));
+                EXPECT_OK(s2n_test_security_policies_compatible(&security_policy_20250429, "default_fips", ecdsa_sha384_chain_and_key));
+                EXPECT_OK(s2n_test_security_policies_compatible(&security_policy_20250429, "20250211", ecdsa_sha384_chain_and_key));
 
                 /* default_tls13 is currently 20240503 */
                 EXPECT_OK(s2n_test_security_policies_compatible(&security_policy_20240503, "rfc9151", ecdsa_sha384_chain_and_key));
@@ -837,9 +869,9 @@ int main(int argc, char **argv)
 
             /* 20250414 */
             {
-                EXPECT_OK(s2n_test_security_policies_compatible(&security_policy_rfc9151, "default_tls13", ecdsa_sha384_chain_and_key));
-                EXPECT_OK(s2n_test_security_policies_compatible(&security_policy_rfc9151, "default_fips", ecdsa_sha384_chain_and_key));
-                EXPECT_OK(s2n_test_security_policies_compatible(&security_policy_rfc9151, "20250414", ecdsa_sha384_chain_and_key));
+                EXPECT_OK(s2n_test_security_policies_compatible(&security_policy_20250429, "default_tls13", ecdsa_sha384_chain_and_key));
+                EXPECT_OK(s2n_test_security_policies_compatible(&security_policy_20250429, "default_fips", ecdsa_sha384_chain_and_key));
+                EXPECT_OK(s2n_test_security_policies_compatible(&security_policy_20250429, "20250414", ecdsa_sha384_chain_and_key));
 
                 /* default_tls13 is currently 20240503 */
                 EXPECT_OK(s2n_test_security_policies_compatible(&security_policy_20240503, "rfc9151", ecdsa_sha384_chain_and_key));
@@ -873,16 +905,22 @@ int main(int argc, char **argv)
             const struct s2n_security_policy *versioned_policies[] = {
                 &security_policy_20170210,
                 &security_policy_20240501,
+                &security_policy_20251014,
             };
 
-            const struct s2n_supported_cert supported_certs[] = {
-                { .cert = rsa_chain_and_key },
-                { .cert = ecdsa_chain_and_key, .start_index = 1 },
-            };
+            DEFER_CLEANUP(struct s2n_test_cert_chain_list cert_chains = { 0 },
+                    s2n_test_cert_chains_free);
+            EXPECT_OK(s2n_test_cert_chains_init(&cert_chains));
+            EXPECT_OK(s2n_test_cert_chains_set_supported(&cert_chains,
+                    S2N_PKEY_TYPE_ECDSA, 1));
+            EXPECT_OK(s2n_test_cert_chains_set_supported(&cert_chains,
+                    S2N_PKEY_TYPE_RSA_PSS, S2N_TEST_CERT_UNSUPPORTED));
+            EXPECT_OK(s2n_test_cert_chains_set_supported(&cert_chains,
+                    S2N_PKEY_TYPE_MLDSA, S2N_TEST_CERT_UNSUPPORTED));
 
             EXPECT_OK(s2n_test_default_backwards_compatible("default",
                     versioned_policies, s2n_array_len(versioned_policies),
-                    supported_certs, s2n_array_len(supported_certs)));
+                    &cert_chains));
         };
 
         /* "default_tls13" */
@@ -892,15 +930,28 @@ int main(int argc, char **argv)
                 &security_policy_20240503,
             };
 
-            const struct s2n_supported_cert supported_certs[] = {
-                { .cert = rsa_chain_and_key },
-                { .cert = ecdsa_chain_and_key },
-                { .cert = rsa_pss_chain_and_key },
-            };
+            DEFER_CLEANUP(struct s2n_test_cert_chain_list cert_chains = { 0 },
+                    s2n_test_cert_chains_free);
+            EXPECT_OK(s2n_test_cert_chains_init(&cert_chains));
+            EXPECT_OK(s2n_test_cert_chains_set_supported(&cert_chains,
+                    S2N_PKEY_TYPE_MLDSA, S2N_TEST_CERT_UNSUPPORTED));
 
             EXPECT_OK(s2n_test_default_backwards_compatible("default_tls13",
                     versioned_policies, s2n_array_len(versioned_policies),
-                    supported_certs, s2n_array_len(supported_certs)));
+                    &cert_chains));
+
+            /* default_tls13 should also be compatible with S2N_POLICY_STRICT
+             * to allow customers to safely upgrade.
+             */
+            if (s2n_is_tls13_fully_supported()) {
+                for (uint64_t i = 1; i <= S2N_STRICT_LATEST_1; i++) {
+                    const struct s2n_security_policy *strict_policy =
+                            s2n_security_policy_get(S2N_POLICY_STRICT, i);
+                    EXPECT_OK(s2n_test_default_backwards_compatible_for_policy(strict_policy,
+                            versioned_policies, s2n_array_len(versioned_policies),
+                            &cert_chains));
+                }
+            }
         };
 
         /* "default_fips" */
@@ -908,16 +959,70 @@ int main(int argc, char **argv)
             const struct s2n_security_policy *versioned_policies[] = {
                 &security_policy_20240416,
                 &security_policy_20240502,
+                &security_policy_20251015,
             };
 
-            const struct s2n_supported_cert supported_certs[] = {
-                { .cert = rsa_chain_and_key },
-                { .cert = ecdsa_chain_and_key },
-            };
+            DEFER_CLEANUP(struct s2n_test_cert_chain_list cert_chains = { 0 },
+                    s2n_test_cert_chains_free);
+            EXPECT_OK(s2n_test_cert_chains_init(&cert_chains));
+            EXPECT_OK(s2n_test_cert_chains_set_supported(&cert_chains,
+                    S2N_PKEY_TYPE_RSA_PSS, S2N_TEST_CERT_UNSUPPORTED));
+            EXPECT_OK(s2n_test_cert_chains_set_supported(&cert_chains,
+                    S2N_PKEY_TYPE_MLDSA, S2N_TEST_CERT_UNSUPPORTED));
 
             EXPECT_OK(s2n_test_default_backwards_compatible("default_fips",
                     versioned_policies, s2n_array_len(versioned_policies),
-                    supported_certs, s2n_array_len(supported_certs)));
+                    &cert_chains));
+        };
+
+        /* "default_pq" */
+        {
+            const struct s2n_security_policy *versioned_policies[] = {
+                &security_policy_20240730,
+                &security_policy_20241001,
+                &security_policy_20250512,
+                &security_policy_20250721,
+            };
+
+            DEFER_CLEANUP(struct s2n_test_cert_chain_list cert_chains = { 0 },
+                    s2n_test_cert_chains_free);
+            EXPECT_OK(s2n_test_cert_chains_init(&cert_chains));
+            EXPECT_OK(s2n_test_cert_chains_set_supported(&cert_chains,
+                    S2N_PKEY_TYPE_MLDSA, 2));
+
+            EXPECT_OK(s2n_test_default_backwards_compatible("default_pq",
+                    versioned_policies, s2n_array_len(versioned_policies),
+                    &cert_chains));
+
+            /* default_pq should also be compatible with S2N_POLICY_STRICT
+             * to allow customers to safely upgrade.
+             */
+            if (s2n_is_tls13_fully_supported()) {
+                for (uint64_t i = 1; i <= S2N_STRICT_LATEST_1; i++) {
+                    const struct s2n_security_policy *strict_policy =
+                            s2n_security_policy_get(S2N_POLICY_STRICT, i);
+                    EXPECT_OK(s2n_test_default_backwards_compatible_for_policy(strict_policy,
+                            versioned_policies, s2n_array_len(versioned_policies),
+                            &cert_chains));
+                }
+            }
+        };
+
+        /* "rfc9151" */
+        {
+            const struct s2n_security_policy *versioned_policies[] = {
+                &security_policy_20250429,
+                &security_policy_20251013,
+            };
+
+            struct s2n_test_cert_chain_list cert_chains = {
+                .chains = { { .chain = ecdsa_sha384_chain_and_key } },
+                .count = 1,
+            };
+
+            EXPECT_OK(s2n_test_default_backwards_compatible("rfc9151",
+                    versioned_policies, s2n_array_len(versioned_policies),
+                    &cert_chains));
         };
     };
 
