@@ -42,6 +42,7 @@ void mock_client(struct s2n_test_io_pair *io_pair)
     conn = s2n_connection_new(S2N_CLIENT);
     config = s2n_config_new();
     s2n_config_disable_x509_verification(config);
+    EXPECT_OK(s2n_config_set_tls12_security_policy(config));
     s2n_connection_set_config(conn, config);
 
     s2n_connection_set_io_pair(conn, io_pair);
@@ -122,7 +123,7 @@ int main(int argc, char **argv)
         EXPECT_NOT_NULL(conn = s2n_connection_new(S2N_SERVER));
 
         EXPECT_NOT_NULL(config = s2n_config_new());
-        EXPECT_SUCCESS(s2n_config_set_cipher_preferences(config, "default"));
+        EXPECT_SUCCESS(s2n_config_set_cipher_preferences(config, "20240501"));
         for (int cert = 0; cert < SUPPORTED_CERTIFICATE_FORMATS; cert++) {
             EXPECT_SUCCESS(s2n_read_test_pem(certificate_paths[cert], cert_chain_pem, S2N_MAX_TEST_PEM_SIZE));
             EXPECT_SUCCESS(s2n_read_test_pem(private_key_paths[cert], private_key_pem, S2N_MAX_TEST_PEM_SIZE));
@@ -175,5 +176,4 @@ int main(int argc, char **argv)
     }
 
     END_TEST();
-    return 0;
 }
