@@ -30,9 +30,10 @@
 #define LENGTH       (s2n_array_len(test_signature_schemes))
 #define STUFFER_SIZE (LENGTH * TLS_SIGNATURE_SCHEME_LEN + 10)
 
-#define RSA_CIPHER_SUITE   &s2n_ecdhe_rsa_with_aes_128_cbc_sha
-#define ECDSA_CIPHER_SUITE &s2n_ecdhe_ecdsa_with_aes_128_cbc_sha
-#define TLS13_CIPHER_SUITE &s2n_tls13_aes_128_gcm_sha256
+#define RSA_CIPHER_SUITE     &s2n_ecdhe_rsa_with_aes_128_cbc_sha
+#define RSA_KEX_CIPHER_SUITE &s2n_rsa_with_aes_256_gcm_sha384
+#define ECDSA_CIPHER_SUITE   &s2n_ecdhe_ecdsa_with_aes_128_cbc_sha
+#define TLS13_CIPHER_SUITE   &s2n_tls13_aes_128_gcm_sha256
 
 /* The only TLS1.3-only signature schemes are RSA-PSS-PSS, which
  * are difficult to test with due to mixed libcrypto support.
@@ -221,19 +222,52 @@ int main(int argc, char **argv)
     /* s2n_signature_algorithm_select */
     {
         DEFER_CLEANUP(struct s2n_config *server_config = s2n_config_new(), s2n_config_ptr_free);
+        EXPECT_OK(s2n_config_set_tls12_security_policy(server_config));
         EXPECT_SUCCESS(s2n_config_add_cert_chain_and_key_to_store(server_config, rsa_cert_chain));
         EXPECT_SUCCESS(s2n_config_add_cert_chain_and_key_to_store(server_config, ecdsa_cert_chain));
 
         /* Clients can only configure one certificate */
         DEFER_CLEANUP(struct s2n_config *client_ecdsa_config = s2n_config_new(), s2n_config_ptr_free);
+        EXPECT_OK(s2n_config_set_tls12_security_policy(client_ecdsa_config));
         EXPECT_SUCCESS(s2n_config_add_cert_chain_and_key_to_store(client_ecdsa_config, ecdsa_cert_chain));
         DEFER_CLEANUP(struct s2n_config *client_rsa_config = s2n_config_new(), s2n_config_ptr_free);
+        EXPECT_OK(s2n_config_set_tls12_security_policy(client_rsa_config));
         EXPECT_SUCCESS(s2n_config_add_cert_chain_and_key_to_store(client_rsa_config, rsa_cert_chain));
 
         /* TLS1.2 defaults defined by the RFC */
         const struct s2n_signature_scheme *ecdsa_default = &s2n_ecdsa_sha1;
         const struct s2n_signature_scheme *rsa_default = &s2n_rsa_pkcs1_sha1;
 
+        /* Test: do not choose a server signature scheme for RSA kex */
+        {
+            DEFER_CLEANUP(struct s2n_connection *conn = s2n_connection_new(S2N_SERVER),
+                    s2n_connection_ptr_free);
+            EXPECT_SUCCESS(s2n_connection_set_config(conn, client_rsa_config));
+
+            /* Support a wide variety of signature schemes */
+            const struct s2n_signature_scheme *test_schemes[] = {
+                &s2n_ecdsa_sha384,
+                &s2n_rsa_pss_rsae_sha256,
+                &s2n_rsa_pss_pss_sha256,
+                &s2n_rsa_pkcs1_sha256,
+            };
+            struct s2n_local_sig_schemes_context local_context = { 0 };
+            EXPECT_OK(s2n_test_set_local_sig_schemes(conn, &local_context,
+                    test_schemes, s2n_array_len(test_schemes)));
+            EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.peer_sig_scheme_list,
+                    test_schemes, s2n_array_len(test_schemes)));
+
+            /* Test: If RSA kex is chosen, a server signature scheme is NOT chosen. */
+            conn->secure->cipher_suite = RSA_KEX_CIPHER_SUITE;
+            EXPECT_OK(s2n_signature_algorithm_select(conn));
+            EXPECT_EQUAL(conn->handshake_params.server_cert_sig_scheme, &s2n_null_sig_scheme);
+
+            /* Test: A client signature scheme is chosen even for RSA kex */
+            conn->mode = S2N_CLIENT;
+            EXPECT_OK(s2n_signature_algorithm_select(conn));
+            EXPECT_NOT_EQUAL(conn->handshake_params.client_cert_sig_scheme, &s2n_null_sig_scheme);
+        };
+
         /* Test: choose legacy default for <TLS1.2 */
         {
             /* Both the client and server support other signature schemes-- we're
@@ -250,11 +284,12 @@ int main(int argc, char **argv)
             {
                 DEFER_CLEANUP(struct s2n_connection *conn = s2n_connection_new(S2N_CLIENT),
                         s2n_connection_ptr_free);
+                EXPECT_OK(s2n_connection_set_tls12_security_policy(conn));
 
                 struct s2n_local_sig_schemes_context local_context = { 0 };
                 EXPECT_OK(s2n_test_set_local_sig_schemes(conn, &local_context,
                         test_schemes, s2n_array_len(test_schemes)));
-                EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.server_sig_hash_algs,
+                EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.peer_sig_scheme_list,
                         test_schemes, s2n_array_len(test_schemes)));
 
                 /* Test: ECDSA */
@@ -301,7 +336,7 @@ int main(int argc, char **argv)
                 struct s2n_local_sig_schemes_context local_context = { 0 };
                 EXPECT_OK(s2n_test_set_local_sig_schemes(conn, &local_context,
                         test_schemes, s2n_array_len(test_schemes)));
-                EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.client_sig_hash_algs,
+                EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.peer_sig_scheme_list,
                         test_schemes, s2n_array_len(test_schemes)));
 
                 /* Test: ECDSA */
@@ -348,7 +383,7 @@ int main(int argc, char **argv)
 
             struct s2n_local_sig_schemes_context local_context = { 0 };
             EXPECT_OK(s2n_test_set_local_sig_schemes(conn, &local_context, &expected, 1));
-            EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.server_sig_hash_algs,
+            EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.peer_sig_scheme_list,
                     &expected, 1));
 
             EXPECT_OK(s2n_signature_algorithm_select(conn));
@@ -367,7 +402,7 @@ int main(int argc, char **argv)
 
             struct s2n_local_sig_schemes_context local_context = { 0 };
             EXPECT_OK(s2n_test_set_local_sig_schemes(conn, &local_context, &expected, 1));
-            EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.server_sig_hash_algs,
+            EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.peer_sig_scheme_list,
                     &expected, 1));
 
             EXPECT_OK(s2n_signature_algorithm_select(conn));
@@ -398,7 +433,7 @@ int main(int argc, char **argv)
             {
                 EXPECT_OK(s2n_test_set_local_sig_schemes(conn, &local_context,
                         order, s2n_array_len(order)));
-                EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.client_sig_hash_algs,
+                EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.peer_sig_scheme_list,
                         reversed_order, s2n_array_len(reversed_order)));
 
                 EXPECT_OK(s2n_signature_algorithm_select(conn));
@@ -409,7 +444,7 @@ int main(int argc, char **argv)
             {
                 EXPECT_OK(s2n_test_set_local_sig_schemes(conn, &local_context,
                         reversed_order, s2n_array_len(reversed_order)));
-                EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.client_sig_hash_algs,
+                EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.peer_sig_scheme_list,
                         order, s2n_array_len(order)));
 
                 EXPECT_OK(s2n_signature_algorithm_select(conn));
@@ -422,7 +457,7 @@ int main(int argc, char **argv)
             {
                 EXPECT_OK(s2n_test_set_local_sig_schemes(conn, &local_context,
                         order, s2n_array_len(order)));
-                EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.client_sig_hash_algs,
+                EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.peer_sig_scheme_list,
                         order, s2n_array_len(order)));
 
                 EXPECT_OK(s2n_signature_algorithm_select(conn));
@@ -444,7 +479,7 @@ int main(int argc, char **argv)
                 struct s2n_local_sig_schemes_context local_context = { 0 };
                 EXPECT_OK(s2n_test_set_local_sig_schemes(conn, &local_context,
                         &invalid, 1));
-                EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.client_sig_hash_algs,
+                EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.peer_sig_scheme_list,
                         &invalid, 1));
 
                 /* Fails for TLS1.3 */
@@ -471,7 +506,7 @@ int main(int argc, char **argv)
                 struct s2n_local_sig_schemes_context local_context = { 0 };
                 EXPECT_OK(s2n_test_set_local_sig_schemes(conn, &local_context,
                         &invalid, 1));
-                EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.client_sig_hash_algs,
+                EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.peer_sig_scheme_list,
                         &invalid, 1));
 
                 /* Fails for TLS1.2 */
@@ -505,7 +540,7 @@ int main(int argc, char **argv)
                 struct s2n_local_sig_schemes_context local_context = { 0 };
                 EXPECT_OK(s2n_test_set_local_sig_schemes(conn, &local_context,
                         &invalid, 1));
-                EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.client_sig_hash_algs,
+                EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.peer_sig_scheme_list,
                         &invalid, 1));
 
                 /* Fails with SHA1 */
@@ -536,7 +571,7 @@ int main(int argc, char **argv)
                 struct s2n_local_sig_schemes_context local_context = { 0 };
                 EXPECT_OK(s2n_test_set_local_sig_schemes(conn, &local_context,
                         &invalid, 1));
-                EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.client_sig_hash_algs,
+                EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.peer_sig_scheme_list,
                         &invalid, 1));
 
                 /* Fails for pkcs1 */
@@ -557,13 +592,14 @@ int main(int argc, char **argv)
 
                 DEFER_CLEANUP(struct s2n_connection *conn = s2n_connection_new(S2N_CLIENT),
                         s2n_connection_ptr_free);
+                EXPECT_OK(s2n_connection_set_tls12_security_policy(conn));
                 conn->actual_protocol_version = S2N_TLS12;
                 conn->secure->cipher_suite = RSA_CIPHER_SUITE;
 
                 struct s2n_local_sig_schemes_context local_context = { 0 };
                 EXPECT_OK(s2n_test_set_local_sig_schemes(conn, &local_context,
                         &scheme, 1));
-                EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.server_sig_hash_algs,
+                EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.peer_sig_scheme_list,
                         &scheme, 1));
 
                 /* Fails for default config with no certs */
@@ -588,13 +624,14 @@ int main(int argc, char **argv)
 
                 DEFER_CLEANUP(struct s2n_connection *conn = s2n_connection_new(S2N_CLIENT),
                         s2n_connection_ptr_free);
+                EXPECT_OK(s2n_connection_set_tls12_security_policy(conn));
                 conn->actual_protocol_version = S2N_TLS12;
                 conn->secure->cipher_suite = ECDSA_CIPHER_SUITE;
 
                 struct s2n_local_sig_schemes_context local_context = { 0 };
                 EXPECT_OK(s2n_test_set_local_sig_schemes(conn, &local_context,
                         &scheme, 1));
-                EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.server_sig_hash_algs,
+                EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.peer_sig_scheme_list,
                         &scheme, 1));
 
                 /* Fails for default config with no certs */
@@ -625,6 +662,7 @@ int main(int argc, char **argv)
 
                 DEFER_CLEANUP(struct s2n_connection *conn = s2n_connection_new(S2N_SERVER),
                         s2n_connection_ptr_free);
+                EXPECT_OK(s2n_connection_set_tls12_security_policy(conn));
                 conn->actual_protocol_version = S2N_TLS13;
                 conn->secure->cipher_suite = TLS13_CIPHER_SUITE;
                 EXPECT_SUCCESS(s2n_connection_set_config(conn, server_config));
@@ -634,7 +672,7 @@ int main(int argc, char **argv)
                 /* Fails with wrong curve (256) */
                 EXPECT_OK(s2n_test_set_local_sig_schemes(conn, &local_context,
                         &ecdsa256, 1));
-                EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.client_sig_hash_algs,
+                EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.peer_sig_scheme_list,
                         &ecdsa256, 1));
                 EXPECT_ERROR_WITH_ERRNO(
                         s2n_signature_algorithm_select(conn),
@@ -643,7 +681,7 @@ int main(int argc, char **argv)
                 /* Succeeds with right curve (384) */
                 EXPECT_OK(s2n_test_set_local_sig_schemes(conn, &local_context,
                         &ecdsa384, 1));
-                EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.client_sig_hash_algs,
+                EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.peer_sig_scheme_list,
                         &ecdsa384, 1));
                 EXPECT_OK(s2n_signature_algorithm_select(conn));
             };
@@ -673,7 +711,7 @@ int main(int argc, char **argv)
             struct s2n_local_sig_schemes_context local_context = { 0 };
             EXPECT_OK(s2n_test_set_local_sig_schemes(conn, &local_context,
                     schemes, s2n_array_len(schemes)));
-            EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.server_sig_hash_algs,
+            EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.peer_sig_scheme_list,
                     schemes, s2n_array_len(schemes)));
 
             EXPECT_OK(s2n_signature_algorithm_select(conn));
@@ -702,7 +740,7 @@ int main(int argc, char **argv)
             struct s2n_local_sig_schemes_context local_context = { 0 };
             EXPECT_OK(s2n_test_set_local_sig_schemes(conn, &local_context,
                     local_schemes, s2n_array_len(local_schemes)));
-            EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.client_sig_hash_algs,
+            EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.peer_sig_scheme_list,
                     peer_schemes, s2n_array_len(peer_schemes)));
 
             EXPECT_OK(s2n_signature_algorithm_select(conn));
@@ -852,7 +890,7 @@ int main(int argc, char **argv)
                 struct s2n_local_sig_schemes_context local_context = { 0 };
                 EXPECT_OK(s2n_test_set_local_sig_schemes(conn, &local_context,
                         local_schemes, s2n_array_len(local_schemes)));
-                EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.client_sig_hash_algs,
+                EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.peer_sig_scheme_list,
                         peer_schemes, s2n_array_len(peer_schemes)));
 
                 /* ECDSA */
@@ -893,7 +931,7 @@ int main(int argc, char **argv)
                 struct s2n_local_sig_schemes_context local_context = { 0 };
                 EXPECT_OK(s2n_test_set_local_sig_schemes(conn, &local_context,
                         local_schemes, s2n_array_len(local_schemes)));
-                EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.client_sig_hash_algs,
+                EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.peer_sig_scheme_list,
                         peer_schemes, s2n_array_len(peer_schemes)));
 
                 EXPECT_OK(s2n_signature_algorithm_select(conn));
@@ -1056,6 +1094,30 @@ int main(int argc, char **argv)
         };
     };
 
+    /* Test: Ensure that the maximum number of permitted signature schemes can be received. */
+    const uint16_t max_sig_schemes = TLS_SIGNATURE_SCHEME_LIST_MAX_LEN;
+    for (uint16_t count = max_sig_schemes - 1; count <= max_sig_schemes + 1; count++) {
+        DEFER_CLEANUP(struct s2n_connection *conn = s2n_connection_new(S2N_CLIENT),
+                s2n_connection_ptr_free);
+        EXPECT_NOT_NULL(conn);
+
+        DEFER_CLEANUP(struct s2n_stuffer input = { 0 }, s2n_stuffer_free);
+        EXPECT_SUCCESS(s2n_stuffer_growable_alloc(&input, 0));
+
+        uint16_t sig_scheme_list_size = count * TLS_SIGNATURE_SCHEME_LEN;
+        EXPECT_SUCCESS(s2n_stuffer_write_uint16(&input, sig_scheme_list_size));
+        for (size_t i = 0; i < count; i++) {
+            EXPECT_SUCCESS(s2n_stuffer_write_uint16(&input, s2n_rsa_pkcs1_sha256.iana_value));
+        }
+
+        int ret = s2n_recv_supported_sig_scheme_list(&input, &conn->handshake_params.peer_sig_scheme_list);
+        if (count <= max_sig_schemes) {
+            EXPECT_SUCCESS(ret);
+        } else {
+            EXPECT_FAILURE_WITH_ERRNO(ret, S2N_ERR_TOO_MANY_SIGNATURE_SCHEMES);
+        }
+    }
+
     /* Test: send and receive default signature preferences */
     for (size_t i = S2N_TLS10; i < S2N_TLS13; i++) {
         DEFER_CLEANUP(struct s2n_connection *conn = s2n_connection_new(S2N_CLIENT),
@@ -1162,7 +1224,7 @@ int main(int argc, char **argv)
             EXPECT_SUCCESS(s2n_connection_set_config(conn, config));
 
             const struct s2n_signature_scheme *schemes[] = { &s2n_rsa_pss_rsae_sha256 };
-            EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.server_sig_hash_algs,
+            EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.peer_sig_scheme_list,
                     schemes, s2n_array_len(schemes)));
 
             if (s2n_is_rsa_pss_signing_supported()) {
@@ -1182,12 +1244,13 @@ int main(int argc, char **argv)
         {
             DEFER_CLEANUP(struct s2n_connection *conn = s2n_connection_new(S2N_SERVER),
                     s2n_connection_ptr_free);
+            EXPECT_OK(s2n_connection_set_tls12_security_policy(conn));
             conn->secure->cipher_suite = TLS13_CIPHER_SUITE;
             conn->actual_protocol_version = S2N_TLS13;
 
             /* Invalid (PKCS1 not allowed by TLS1.3) */
             const struct s2n_signature_scheme *peer_schemes[] = { &s2n_rsa_pkcs1_sha224 };
-            EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.client_sig_hash_algs,
+            EXPECT_OK(s2n_test_set_peer_sig_schemes(&conn->handshake_params.peer_sig_scheme_list,
                     peer_schemes, s2n_array_len(peer_schemes)));
 
             /* Both PKCS1 and PSS supported */
@@ -1474,6 +1537,40 @@ int main(int argc, char **argv)
         }
     }
 
+    /* Self-Talk test: no server signature scheme is chosen for RSA kex */
+    {
+        DEFER_CLEANUP(struct s2n_config *config = s2n_config_new(), s2n_config_ptr_free);
+        EXPECT_NOT_NULL(config);
+        EXPECT_SUCCESS(s2n_config_set_unsafe_for_testing(config));
+        EXPECT_SUCCESS(s2n_config_add_cert_chain_and_key_to_store(config, rsa_cert_chain));
+        EXPECT_SUCCESS(s2n_config_set_cipher_preferences(config, "test_all_rsa_kex"));
+        EXPECT_SUCCESS(s2n_config_set_client_auth_type(config, S2N_CERT_AUTH_REQUIRED));
+
+        DEFER_CLEANUP(struct s2n_connection *client = s2n_connection_new(S2N_CLIENT),
+                s2n_connection_ptr_free);
+        EXPECT_SUCCESS(s2n_connection_set_config(client, config));
+
+        DEFER_CLEANUP(struct s2n_connection *server = s2n_connection_new(S2N_SERVER),
+                s2n_connection_ptr_free);
+        EXPECT_SUCCESS(s2n_connection_set_config(server, config));
+
+        DEFER_CLEANUP(struct s2n_test_io_stuffer_pair io_pair, s2n_io_stuffer_pair_free);
+        EXPECT_OK(s2n_io_stuffer_pair_init(&io_pair));
+        EXPECT_OK(s2n_connections_set_io_stuffer_pair(client, server, &io_pair));
+        EXPECT_SUCCESS(s2n_negotiate_test_server_and_client(server, client));
+
+        /* RSA kex negotiated */
+        EXPECT_EQUAL(server->secure->cipher_suite->key_exchange_alg, &s2n_rsa);
+
+        /* No server signature scheme */
+        EXPECT_EQUAL(server->handshake_params.server_cert_sig_scheme, &s2n_null_sig_scheme);
+        EXPECT_EQUAL(client->handshake_params.server_cert_sig_scheme, &s2n_null_sig_scheme);
+
+        /* Client signature scheme negotiated */
+        EXPECT_EQUAL(server->handshake_params.client_cert_sig_scheme, &s2n_rsa_pkcs1_sha256);
+        EXPECT_EQUAL(client->handshake_params.client_cert_sig_scheme, &s2n_rsa_pkcs1_sha256);
+    };
+
     END_TEST();
 
     return 0;
